#-*- coding: iso-8859-15 -*-

###########################################################################
# TextIndexNG V 3                
# The next generation TextIndex for Zope
#
# This software is governed by a license. See
# LICENSE.txt for the terms of this license.
###########################################################################

# some texts for test cases

de1 = """
Gleich ihr ist er Reflexionsbestimmung. Das Opfer wird uns frei machen, was
historisch den Sprachen ohnehin widerfuhr. (6) Heideggers Lehre läuft ungewollt
auf eine Exegese des schnöden Witzes "Umsonst ist der Tod", so hat bei den
existentiellen Eigentlichen selbst der Existentialismus nichts zu lachen: Je
weniger das für sich seiende Subjekt vermag; tiefinnerstes Anliegen sein
müssen, bei denen Verwaltungsmänner, als Ganzes. (7)(8) Aber die falsche Würde
hat nicht immer Unrecht, weil man tief sein will, die seiner Sprache folgten,
was er im gleichen Augenblick tut: 
"""

de2 = """
Auch Heidegger begegnete dem Nichts nur zur höheren Propädeutik des Seins.
Spätbürgerliches Denken bildet sich zurück zur nackten Selbsterhaltung, was
bloß jenem Vorteil dient. (5)(6)(7) Das sichtbar zu machen, echtes Gespräch,
welche einst dem Denken zur Emanzipation verhalf. Sie sucht das Neue nur,
daseiend, die ihrerseits wieder durch Erinnerung an Theologie mehr sein wollen,
was seinem Sinn nach daraus folgen sollte. 
"""

de3 = """
Deshalb besteht der formale Schluß von dem überdies ontologisch unangemessen
als Ausstand interpretierten Noch-nicht des Daseins auf seine Unganzheit nicht
zurecht. Wer die Warenwelt als das "An sich" akzeptiert, versteift die
triebfeindlichen Tabus der Innerlichen. (1) Unterschlagen ist, worin sie
geheimes Einverständnis erwartet, mit welchen er das Wort Mensch Emanzipation registriert,
richtiges Leben definiert durch Entscheidung schlechthin. 
"""

en1 = """
 If one examines semioticist discourse, one is faced with a choice: either
reject postpatriarchial conceptualist theory or conclude that sexual identity
has intrinsic meaning. If prepatriarchial deconstruction holds, we have to
choose between the neocultural paradigm of narrative and cultural subdialectic
theory.
"""

en2 = """
It could be said that the premise of semanticist narrative suggests that
sexuality is used to oppress minorities, but only if art is distinct from
language; if that is not the case, we can assume that the raison d'etre of the
artist is deconstruction. Lyotard promotes the use of capitalist subcultural
theory to challenge sexist perceptions of society.
"""

en3 = """
Therefore, Baudrillard's model of predialectic situationism implies that the
establishment is intrinsically responsible for capitalism, given that the
premise of the neocultural paradigm of narrative is invalid. Dahmus[1] suggests
that we have to choose between postpatriarchial conceptualist theory and
textual objectivism. 
"""

fr1 = """
Benoît XVI a inauguré aujourd'hui son pontificat avec une messe solennelle de
près de trois heures célébrée place Saint Pierre devant 350.000 fidèles, habité
par le souvenir de son prédécesseur Jean Paul II, et par la volonté d'agir pour
l'unité de tous les chrétiens. ...
"""

fr2 = """
Pour les autres pièces d'habillement, la hausse des importations varie de 63%
pour les soutiens-gorge à 413% sur les pantalons pour homme.
"""

fr3 = """
Sur les neuf catégories, sept répondent aux demandes du groupe de pression
textile européen Euratex qui avait mis en cause un "tsunami" d'importations
chinoises pour douze produits. Les autres demandent "une poursuite de
l'analyse", a dit le commissaire. En revanche, les T-shirts et un type de fil,
non mentionnés par Euratex appellent également une action, selon Bruxelles.
"""

